PinRowCommand class

Inheritance

Constructors

PinRowCommand(String rowId, RowPinPosition position, {GridState? prevState})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
position → RowPinPosition
final
prevState → GridState?
final
rowId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
undoable → bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withPrevState(GridState state) → GridCommand
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited