RowModel<T> class

A processed row model.

Constructors

RowModel({required String id, required T original, required int index, int originalIndex = -1, bool isSelected = false, bool isExpanded = false, bool isPinnedTop = false, bool isPinnedBottom = false, List<RowModel<T>> subRows = const [], int depth = 0, RowModel<T>? parentRow, bool isGrouped = false, bool isAggregated = false, String? groupingColumnId, dynamic groupingValue, dynamic controller})

Properties

depth → int
final
groupingColumnId → String?
final
groupingValue → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
index → int
final
isAggregated → bool
final
isExpanded → bool
final
isGrouped → bool
final
isPinnedBottom → bool
final
isPinnedTop → bool
final
isSelected → bool
final
original → T
final
originalIndex → int
final
parentRow → RowModel<T>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subRows → List<RowModel<T>>
final

Methods

copyWith({String? id, T? original, int? index, int? originalIndex, bool? isSelected, bool? isExpanded, bool? isPinnedTop, bool? isPinnedBottom, List<RowModel<T>>? subRows, int? depth, RowModel<T>? parentRow, bool? isGrouped, bool? isAggregated, String? groupingColumnId, dynamic groupingValue, dynamic controller}) → RowModel<T>
getVisibleCells(List<ColumnInfo<T, Object?>> columns) → List<CellModel<T, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pinBottom() → void
pinTop() → void
toggleExpanded() → void
toggleSelected() → void
toString() → String
A string representation of this object.
inherited
unpin() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited